pub enum ResponseType {
Regular(Response),
}Expand description
An enum that represents either a regular response or a stream response. This allows the framework to handle both response types in a unified way.
Variants
Implementations
Sourceimpl ResponseType
impl ResponseType
Sourcepub fn from_regular(response: Response) -> ResponseType
pub fn from_regular(response: Response) -> ResponseType
Converts a regular response to the enum.
Sourcepub fn status(&self) -> StatusCode
pub fn status(&self) -> StatusCode
Gets the status code from the response regardless of type.
Sourcepub fn request_url(&self) -> &Url
pub fn request_url(&self) -> &Url
Gets the request URL from the response regardless of type.