pub struct CrawlerState {
pub in_flight_requests: Atomic<usize>,
pub parsing_responses: Atomic<usize>,
pub processing_items: Atomic<usize>,
pub admitted_items: Atomic<usize>,
pub item_limit_reached: Atomic<bool>,
}Expand description
Core runtime types and traits used to define and run a crawl. Internal shared state used by the runtime.
Fields
in_flight_requests: Atomic<usize>The number of requests currently being downloaded.
parsing_responses: Atomic<usize>The number of responses currently being parsed.
processing_items: Atomic<usize>The number of items currently being processed by pipelines.
admitted_items: Atomic<usize>The number of scraped items admitted into the processing pipeline.
item_limit_reached: Atomic<bool>Indicates that the crawl is shutting down because the item limit was reached.
Implementations
Sourceimpl CrawlerState
impl CrawlerState