pub struct RefererMiddleware {
pub same_origin_only: bool,
pub max_chain_length: usize,
pub include_fragment: bool,
/* private fields */
}Expand description
Built-in middleware that is available without extra feature flags.
Middleware that derives Referer values from request metadata and history.
Fields
same_origin_only: boolWhether to use same-origin only referer
max_chain_length: usizeMaximum referer chain length to keep in memory
include_fragment: boolWhether to include fragment in referer URL
Implementations
Sourceimpl RefererMiddleware
impl RefererMiddleware
Sourcepub fn new() -> RefererMiddleware
pub fn new() -> RefererMiddleware
Creates a middleware with default settings.
Sourcepub fn same_origin_only(self, same_origin_only: bool) -> RefererMiddleware
pub fn same_origin_only(self, same_origin_only: bool) -> RefererMiddleware
Set whether to use same-origin only referer.
Sourcepub fn max_chain_length(self, max_chain_length: usize) -> RefererMiddleware
pub fn max_chain_length(self, max_chain_length: usize) -> RefererMiddleware
Set the maximum referer chain length to keep in memory.
Sourcepub fn include_fragment(self, include_fragment: bool) -> RefererMiddleware
pub fn include_fragment(self, include_fragment: bool) -> RefererMiddleware
Set whether to include the fragment in the referer URL.