DiscoveryConfig

Struct DiscoveryConfig 

pub struct DiscoveryConfig {
    pub mode: DiscoveryMode,
    pub discover_sitemaps: bool,
    pub max_sitemap_depth: usize,
    pub extract_page_metadata: bool,
    pub link_extract_options: LinkExtractOptions,
    pub rules: Vec<DiscoveryRule>,
}
Core runtime types and traits used to define and run a crawl. Discovery-specific runtime configuration.

Fields

mode: DiscoveryMode

How the runtime should discover follow-up work from responses.

discover_sitemaps: bool

Whether sitemap XML should be parsed into follow-up requests.

max_sitemap_depth: usize

Maximum recursion depth for nested sitemap indexes.

extract_page_metadata: bool

Whether page metadata should be extracted and attached to response metadata.

link_extract_options: LinkExtractOptions

Base link extraction options used for HTML discovery.

rules: Vec<DiscoveryRule>

Optional rule-like link discovery behavior matched against source responses.

Implementations

Source

impl DiscoveryConfig

pub fn new() -> DiscoveryConfig

Creates a new discovery config with default values.

pub fn with_mode(self, mode: DiscoveryMode) -> DiscoveryConfig

Sets the discovery mode.

pub fn with_sitemaps(self, enabled: bool) -> DiscoveryConfig

Enables or disables sitemap parsing.

pub fn with_max_sitemap_depth(self, depth: usize) -> DiscoveryConfig

Sets the maximum nested sitemap depth.

pub fn with_page_metadata(self, enabled: bool) -> DiscoveryConfig

Enables or disables page metadata extraction.

Replaces the base link extraction options.

pub fn with_rules( self, rules: impl IntoIterator<Item = DiscoveryRule>, ) -> DiscoveryConfig

Replaces the configured discovery rules.

pub fn with_rule(self, rule: DiscoveryRule) -> DiscoveryConfig

Adds a single discovery rule.

pub fn with_same_site_only(self, enabled: bool) -> DiscoveryConfig

Sets whether only same-site links should be discovered.

Sets whether text content should be scanned for plain-text URLs.

pub fn with_allow_patterns( self, patterns: impl IntoIterator<Item = impl Into<String>>, ) -> DiscoveryConfig

Restricts discovery to URLs that match at least one glob-style pattern.

pub fn with_deny_patterns( self, patterns: impl IntoIterator<Item = impl Into<String>>, ) -> DiscoveryConfig

Excludes URLs that match any glob-style pattern.

pub fn with_allow_domains( self, domains: impl IntoIterator<Item = impl Into<String>>, ) -> DiscoveryConfig

Restricts discovery to the given domains or subdomains.

pub fn with_deny_domains( self, domains: impl IntoIterator<Item = impl Into<String>>, ) -> DiscoveryConfig

Excludes discovery for the given domains or subdomains.

pub fn with_allow_path_prefixes( self, prefixes: impl IntoIterator<Item = impl Into<String>>, ) -> DiscoveryConfig

Restricts discovery to URL paths with one of the provided prefixes.

pub fn with_deny_path_prefixes( self, prefixes: impl IntoIterator<Item = impl Into<String>>, ) -> DiscoveryConfig

Excludes URL paths with one of the provided prefixes.

pub fn with_allowed_tags( self, tags: impl IntoIterator<Item = impl Into<String>>, ) -> DiscoveryConfig

Restricts attribute extraction to specific HTML tags.

pub fn with_allowed_attributes( self, attributes: impl IntoIterator<Item = impl Into<String>>, ) -> DiscoveryConfig

Restricts attribute extraction to specific attributes.

Restricts discovery to the provided link types.

Excludes the provided link types from discovery.

Returns the effective link extraction options for the configured mode.

Returns the effective link extraction options for a specific rule or override.

pub fn should_extract_metadata(&self) -> bool

Returns true when metadata extraction should run.