pub struct Request {
pub url: Url,
pub method: Method,
pub headers: HeaderMap,
pub body: Option<Body>,
pub meta: DashMap<Cow<'static, str>, Value>,
}Fields
url: Urlmethod: Methodheaders: HeaderMapbody: Option<Body>meta: DashMap<Cow<'static, str>, Value>Implementations
Sourceimpl Request
impl Request
Sourcepub fn with_method(self, method: Method) -> Request
pub fn with_method(self, method: Method) -> Request
Sets the HTTP method for the request.
Sourcepub fn with_header(
self,
name: &str,
value: &str,
) -> Result<Request, SpiderError>
pub fn with_header( self, name: &str, value: &str, ) -> Result<Request, SpiderError>
Adds a header to the request.
Sourcepub fn with_body(self, body: Body) -> Request
pub fn with_body(self, body: Body) -> Request
Sets the body of the request and defaults the method to POST.
Sourcepub fn with_form(self, form: DashMap<String, String>) -> Request
pub fn with_form(self, form: DashMap<String, String>) -> Request
Sets the body of the request to a form.
Sourcepub fn with_bytes(self, bytes: Bytes) -> Request
pub fn with_bytes(self, bytes: Bytes) -> Request
Sets the body of the request to a byte slice.
Sourcepub fn with_meta(self, key: &str, value: Value) -> Request
pub fn with_meta(self, key: &str, value: Value) -> Request
Adds a value to the request’s metadata.
Sourcepub fn get_retry_attempts(&self) -> u32
pub fn get_retry_attempts(&self) -> u32
Gets the number of times the request has been retried.
Sourcepub fn increment_retry_attempts(&mut self)
pub fn increment_retry_attempts(&mut self)
Increments the retry count for the request.
Sourcepub fn fingerprint(&self) -> String
pub fn fingerprint(&self) -> String
Generates a unique fingerprint for the request based on its URL, method, and body.